
'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/provider/v2/msg.proto\x12\x14sentinel.provider.v2\x1a\x14gogoproto/gogo.proto\x1a\x1esentinel/types/v1/status.proto"g\n\x12MsgRegisterRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08identity\x18\x03 \x01(\t\x12\x0f\n\x07website\x18\x04 \x01(\t\x12\x13\n\x0bdescription\x18\x05 \x01(\t"\x90\x01\n\x10MsgUpdateRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08identity\x18\x03 \x01(\t\x12\x0f\n\x07website\x18\x04 \x01(\t\x12\x13\n\x0bdescription\x18\x05 \x01(\t\x12)\n\x06status\x18\x06 \x01(\x0e2\x19.sentinel.types.v1.Status"\x15\n\x13MsgRegisterResponse"\x13\n\x11MsgUpdateResponse2\xce\x01\n\nMsgService\x12b\n\x0bMsgRegister\x12(.sentinel.provider.v2.MsgRegisterRequest\x1a).sentinel.provider.v2.MsgRegisterResponse\x12\\\n\tMsgUpdate\x12&.sentinel.provider.v2.MsgUpdateRequest\x1a\'.sentinel.provider.v2.MsgUpdateResponseB;Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.provider.v2.msg_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _MSGREGISTERREQUEST._serialized_start = 110
    _MSGREGISTERREQUEST._serialized_end = 213
    _MSGUPDATEREQUEST._serialized_start = 216
    _MSGUPDATEREQUEST._serialized_end = 360
    _MSGREGISTERRESPONSE._serialized_start = 362
    _MSGREGISTERRESPONSE._serialized_end = 383
    _MSGUPDATERESPONSE._serialized_start = 385
    _MSGUPDATERESPONSE._serialized_end = 404
    _MSGSERVICE._serialized_start = 407
    _MSGSERVICE._serialized_end = 613




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ....cosmos.authz.v1beta1 import query_pb2 as cosmos_dot_authz_dot_v1beta1_dot_query__pb2

class QueryStub(object):
    'Query defines the gRPC querier service.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.Grants = channel.unary_unary('/cosmos.authz.v1beta1.Query/Grants', request_serializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGrantsRequest.SerializeToString, response_deserializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGrantsResponse.FromString)
        self.GranterGrants = channel.unary_unary('/cosmos.authz.v1beta1.Query/GranterGrants', request_serializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranterGrantsRequest.SerializeToString, response_deserializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranterGrantsResponse.FromString)
        self.GranteeGrants = channel.unary_unary('/cosmos.authz.v1beta1.Query/GranteeGrants', request_serializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranteeGrantsRequest.SerializeToString, response_deserializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranteeGrantsResponse.FromString)

class QueryServicer(object):
    'Query defines the gRPC querier service.\n    '

    def Grants(self, request, context):
        'Returns list of `Authorization`, granted to the grantee by the granter.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GranterGrants(self, request, context):
        'GranterGrants returns list of `GrantAuthorization`, granted by granter.\n\n        Since: cosmos-sdk 0.45.2\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GranteeGrants(self, request, context):
        'GranteeGrants returns a list of `GrantAuthorization` by grantee.\n\n        Since: cosmos-sdk 0.45.2\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {'Grants': grpc.unary_unary_rpc_method_handler(servicer.Grants, request_deserializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGrantsRequest.FromString, response_serializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGrantsResponse.SerializeToString), 'GranterGrants': grpc.unary_unary_rpc_method_handler(servicer.GranterGrants, request_deserializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranterGrantsRequest.FromString, response_serializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranterGrantsResponse.SerializeToString), 'GranteeGrants': grpc.unary_unary_rpc_method_handler(servicer.GranteeGrants, request_deserializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranteeGrantsRequest.FromString, response_serializer=cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranteeGrantsResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('cosmos.authz.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Query defines the gRPC querier service.\n    '

    @staticmethod
    def Grants(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.authz.v1beta1.Query/Grants', cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGrantsRequest.SerializeToString, cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGrantsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GranterGrants(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.authz.v1beta1.Query/GranterGrants', cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranterGrantsRequest.SerializeToString, cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranterGrantsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GranteeGrants(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.authz.v1beta1.Query/GranteeGrants', cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranteeGrantsRequest.SerializeToString, cosmos_dot_authz_dot_v1beta1_dot_query__pb2.QueryGranteeGrantsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from .....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from .....ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ibc/applications/transfer/v1/tx.proto\x12\x1cibc.applications.transfer.v1\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x1fibc/core/client/v1/client.proto"\xd5\x02\n\x0bMsgTransfer\x12+\n\x0bsource_port\x18\x01 \x01(\tB\x16\xf2\xde\x1f\x12yaml:"source_port"\x121\n\x0esource_channel\x18\x02 \x01(\tB\x19\xf2\xde\x1f\x15yaml:"source_channel"\x12.\n\x05token\x18\x03 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06sender\x18\x04 \x01(\t\x12\x10\n\x08receiver\x18\x05 \x01(\t\x12Q\n\x0etimeout_height\x18\x06 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x1d\xf2\xde\x1f\x15yaml:"timeout_height"\xc8\xde\x1f\x00\x127\n\x11timeout_timestamp\x18\x07 \x01(\x04B\x1c\xf2\xde\x1f\x18yaml:"timeout_timestamp":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x15\n\x13MsgTransferResponse2o\n\x03Msg\x12h\n\x08Transfer\x12).ibc.applications.transfer.v1.MsgTransfer\x1a1.ibc.applications.transfer.v1.MsgTransferResponseB9Z7github.com/cosmos/ibc-go/v3/modules/apps/transfer/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v3/modules/apps/transfer/types'
    _MSGTRANSFER.fields_by_name['source_port']._options = None
    _MSGTRANSFER.fields_by_name['source_port']._serialized_options = b'\xf2\xde\x1f\x12yaml:"source_port"'
    _MSGTRANSFER.fields_by_name['source_channel']._options = None
    _MSGTRANSFER.fields_by_name['source_channel']._serialized_options = b'\xf2\xde\x1f\x15yaml:"source_channel"'
    _MSGTRANSFER.fields_by_name['token']._options = None
    _MSGTRANSFER.fields_by_name['token']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGTRANSFER.fields_by_name['timeout_height']._options = None
    _MSGTRANSFER.fields_by_name['timeout_height']._serialized_options = b'\xf2\xde\x1f\x15yaml:"timeout_height"\xc8\xde\x1f\x00'
    _MSGTRANSFER.fields_by_name['timeout_timestamp']._options = None
    _MSGTRANSFER.fields_by_name['timeout_timestamp']._serialized_options = b'\xf2\xde\x1f\x18yaml:"timeout_timestamp"'
    _MSGTRANSFER._options = None
    _MSGTRANSFER._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGTRANSFER._serialized_start = 159
    _MSGTRANSFER._serialized_end = 500
    _MSGTRANSFERRESPONSE._serialized_start = 502
    _MSGTRANSFERRESPONSE._serialized_end = 523
    _MSG._serialized_start = 525
    _MSG._serialized_end = 636




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class ParamChange(_message.Message):
    __slots__ = ['key', 'subspace', 'value']
    KEY_FIELD_NUMBER: _ClassVar[int]
    SUBSPACE_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    subspace: str
    value: str

    def __init__(self, subspace: _Optional[str]=..., key: _Optional[str]=..., value: _Optional[str]=...) -> None:
        ...

class ParameterChangeProposal(_message.Message):
    __slots__ = ['changes', 'description', 'title']
    CHANGES_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    changes: _containers.RepeatedCompositeFieldContainer[ParamChange]
    description: str
    title: str

    def __init__(self, title: _Optional[str]=..., description: _Optional[str]=..., changes: _Optional[_Iterable[_Union[(ParamChange, _Mapping)]]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1atendermint/p2p/types.proto\x12\x0etendermint.p2p\x1a\x14gogoproto/gogo.proto"B\n\nNetAddress\x12\x12\n\x02id\x18\x01 \x01(\tB\x06\xe2\xde\x1f\x02ID\x12\x12\n\x02ip\x18\x02 \x01(\tB\x06\xe2\xde\x1f\x02IP\x12\x0c\n\x04port\x18\x03 \x01(\r"C\n\x0fProtocolVersion\x12\x14\n\x03p2p\x18\x01 \x01(\x04B\x07\xe2\xde\x1f\x03P2P\x12\r\n\x05block\x18\x02 \x01(\x04\x12\x0b\n\x03app\x18\x03 \x01(\x04"\x93\x02\n\x0fDefaultNodeInfo\x12?\n\x10protocol_version\x18\x01 \x01(\x0b2\x1f.tendermint.p2p.ProtocolVersionB\x04\xc8\xde\x1f\x00\x12*\n\x0fdefault_node_id\x18\x02 \x01(\tB\x11\xe2\xde\x1f\rDefaultNodeID\x12\x13\n\x0blisten_addr\x18\x03 \x01(\t\x12\x0f\n\x07network\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x10\n\x08channels\x18\x06 \x01(\x0c\x12\x0f\n\x07moniker\x18\x07 \x01(\t\x129\n\x05other\x18\x08 \x01(\x0b2$.tendermint.p2p.DefaultNodeInfoOtherB\x04\xc8\xde\x1f\x00"M\n\x14DefaultNodeInfoOther\x12\x10\n\x08tx_index\x18\x01 \x01(\t\x12#\n\x0brpc_address\x18\x02 \x01(\tB\x0e\xe2\xde\x1f\nRPCAddressB7Z5github.com/tendermint/tendermint/proto/tendermint/p2pb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.p2p.types_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/tendermint/tendermint/proto/tendermint/p2p'
    _NETADDRESS.fields_by_name['id']._options = None
    _NETADDRESS.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _NETADDRESS.fields_by_name['ip']._options = None
    _NETADDRESS.fields_by_name['ip']._serialized_options = b'\xe2\xde\x1f\x02IP'
    _PROTOCOLVERSION.fields_by_name['p2p']._options = None
    _PROTOCOLVERSION.fields_by_name['p2p']._serialized_options = b'\xe2\xde\x1f\x03P2P'
    _DEFAULTNODEINFO.fields_by_name['protocol_version']._options = None
    _DEFAULTNODEINFO.fields_by_name['protocol_version']._serialized_options = b'\xc8\xde\x1f\x00'
    _DEFAULTNODEINFO.fields_by_name['default_node_id']._options = None
    _DEFAULTNODEINFO.fields_by_name['default_node_id']._serialized_options = b'\xe2\xde\x1f\rDefaultNodeID'
    _DEFAULTNODEINFO.fields_by_name['other']._options = None
    _DEFAULTNODEINFO.fields_by_name['other']._serialized_options = b'\xc8\xde\x1f\x00'
    _DEFAULTNODEINFOOTHER.fields_by_name['rpc_address']._options = None
    _DEFAULTNODEINFOOTHER.fields_by_name['rpc_address']._serialized_options = b'\xe2\xde\x1f\nRPCAddress'
    _NETADDRESS._serialized_start = 68
    _NETADDRESS._serialized_end = 134
    _PROTOCOLVERSION._serialized_start = 136
    _PROTOCOLVERSION._serialized_end = 203
    _DEFAULTNODEINFO._serialized_start = 206
    _DEFAULTNODEINFO._serialized_end = 481
    _DEFAULTNODEINFOOTHER._serialized_start = 483
    _DEFAULTNODEINFOOTHER._serialized_end = 560




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class BlockParams(_message.Message):
    __slots__ = ['max_bytes', 'max_gas', 'time_iota_ms']
    MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    MAX_GAS_FIELD_NUMBER: _ClassVar[int]
    TIME_IOTA_MS_FIELD_NUMBER: _ClassVar[int]
    max_bytes: int
    max_gas: int
    time_iota_ms: int

    def __init__(self, max_bytes: _Optional[int]=..., max_gas: _Optional[int]=..., time_iota_ms: _Optional[int]=...) -> None:
        ...

class ConsensusParams(_message.Message):
    __slots__ = ['block', 'evidence', 'validator', 'version']
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    block: BlockParams
    evidence: EvidenceParams
    validator: ValidatorParams
    version: VersionParams

    def __init__(self, block: _Optional[_Union[(BlockParams, _Mapping)]]=..., evidence: _Optional[_Union[(EvidenceParams, _Mapping)]]=..., validator: _Optional[_Union[(ValidatorParams, _Mapping)]]=..., version: _Optional[_Union[(VersionParams, _Mapping)]]=...) -> None:
        ...

class EvidenceParams(_message.Message):
    __slots__ = ['max_age_duration', 'max_age_num_blocks', 'max_bytes']
    MAX_AGE_DURATION_FIELD_NUMBER: _ClassVar[int]
    MAX_AGE_NUM_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    max_age_duration: _duration_pb2.Duration
    max_age_num_blocks: int
    max_bytes: int

    def __init__(self, max_age_num_blocks: _Optional[int]=..., max_age_duration: _Optional[_Union[(_duration_pb2.Duration, _Mapping)]]=..., max_bytes: _Optional[int]=...) -> None:
        ...

class HashedParams(_message.Message):
    __slots__ = ['block_max_bytes', 'block_max_gas']
    BLOCK_MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    BLOCK_MAX_GAS_FIELD_NUMBER: _ClassVar[int]
    block_max_bytes: int
    block_max_gas: int

    def __init__(self, block_max_bytes: _Optional[int]=..., block_max_gas: _Optional[int]=...) -> None:
        ...

class ValidatorParams(_message.Message):
    __slots__ = ['pub_key_types']
    PUB_KEY_TYPES_FIELD_NUMBER: _ClassVar[int]
    pub_key_types: _containers.RepeatedScalarFieldContainer[str]

    def __init__(self, pub_key_types: _Optional[_Iterable[str]]=...) -> None:
        ...

class VersionParams(_message.Message):
    __slots__ = ['app_version']
    APP_VERSION_FIELD_NUMBER: _ClassVar[int]
    app_version: int

    def __init__(self, app_version: _Optional[int]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.node.v2 import node_pb2 as _node_pb2
from sentinel.node.v2 import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ['nodes', 'params']
    NODES_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[_node_pb2.Node]
    params: _params_pb2.Params

    def __init__(self, nodes: _Optional[_Iterable[_Union[(_node_pb2.Node, _Mapping)]]]=..., params: _Optional[_Union[(_params_pb2.Params, _Mapping)]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgGrantAllowance(_message.Message):
    __slots__ = ['allowance', 'grantee', 'granter']
    ALLOWANCE_FIELD_NUMBER: _ClassVar[int]
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    allowance: _any_pb2.Any
    grantee: str
    granter: str

    def __init__(self, granter: _Optional[str]=..., grantee: _Optional[str]=..., allowance: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=...) -> None:
        ...

class MsgGrantAllowanceResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgRevokeAllowance(_message.Message):
    __slots__ = ['grantee', 'granter']
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    grantee: str
    granter: str

    def __init__(self, granter: _Optional[str]=..., grantee: _Optional[str]=...) -> None:
        ...

class MsgRevokeAllowanceResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...



from . import auth
from . import authz
from . import bank
from . import base
from . import capability
from . import crisis
from . import crypto
from . import distribution
from . import evidence
from . import feegrant
from . import genutil
from . import gov
from . import ics23
from . import mint
from . import params
from . import slashing
from . import staking
from . import tx
from . import upgrade
from . import vesting




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.cosmos/distribution/v1beta1/distribution.proto\x12\x1bcosmos.distribution.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/base/v1beta1/coin.proto"\x8a\x03\n\x06Params\x12]\n\rcommunity_tax\x18\x01 \x01(\tBF\xf2\xde\x1f\x14yaml:"community_tax"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12k\n\x14base_proposer_reward\x18\x02 \x01(\tBM\xf2\xde\x1f\x1byaml:"base_proposer_reward"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12m\n\x15bonus_proposer_reward\x18\x03 \x01(\tBN\xf2\xde\x1f\x1cyaml:"bonus_proposer_reward"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12?\n\x15withdraw_addr_enabled\x18\x04 \x01(\x08B \xf2\xde\x1f\x1cyaml:"withdraw_addr_enabled":\x04\x98\xa0\x1f\x00"\xe8\x01\n\x1aValidatorHistoricalRewards\x12\x94\x01\n\x17cumulative_reward_ratio\x18\x01 \x03(\x0b2\x1c.cosmos.base.v1beta1.DecCoinBU\xf2\xde\x1f\x1eyaml:"cumulative_reward_ratio"\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00\x123\n\x0freference_count\x18\x02 \x01(\rB\x1a\xf2\xde\x1f\x16yaml:"reference_count""\x8d\x01\n\x17ValidatorCurrentRewards\x12b\n\x07rewards\x18\x01 \x03(\x0b2\x1c.cosmos.base.v1beta1.DecCoinB3\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00\x12\x0e\n\x06period\x18\x02 \x01(\x04"\x87\x01\n\x1eValidatorAccumulatedCommission\x12e\n\ncommission\x18\x01 \x03(\x0b2\x1c.cosmos.base.v1beta1.DecCoinB3\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00"\x93\x01\n\x1bValidatorOutstandingRewards\x12t\n\x07rewards\x18\x01 \x03(\x0b2\x1c.cosmos.base.v1beta1.DecCoinBE\xf2\xde\x1f\x0eyaml:"rewards"\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00"\x8e\x01\n\x13ValidatorSlashEvent\x125\n\x10validator_period\x18\x01 \x01(\x04B\x1b\xf2\xde\x1f\x17yaml:"validator_period"\x12@\n\x08fraction\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00"\x95\x01\n\x14ValidatorSlashEvents\x12w\n\x16validator_slash_events\x18\x01 \x03(\x0b20.cosmos.distribution.v1beta1.ValidatorSlashEventB%\xf2\xde\x1f\x1dyaml:"validator_slash_events"\xc8\xde\x1f\x00:\x04\x98\xa0\x1f\x00"\x8e\x01\n\x07FeePool\x12\x82\x01\n\x0ecommunity_pool\x18\x01 \x03(\x0b2\x1c.cosmos.base.v1beta1.DecCoinBL\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xf2\xde\x1f\x15yaml:"community_pool""\xbe\x01\n\x1aCommunityPoolSpendProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t\x12\x11\n\trecipient\x18\x03 \x01(\t\x12[\n\x06amount\x18\x04 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00"\xda\x01\n\x15DelegatorStartingInfo\x123\n\x0fprevious_period\x18\x01 \x01(\x04B\x1a\xf2\xde\x1f\x16yaml:"previous_period"\x12M\n\x05stake\x18\x02 \x01(\tB>\xf2\xde\x1f\x0cyaml:"stake"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12=\n\x06height\x18\x03 \x01(\x04B-\xf2\xde\x1f\x16yaml:"creation_height"\xea\xde\x1f\x0fcreation_height"\xc1\x01\n\x19DelegationDelegatorReward\x127\n\x11validator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address"\x12a\n\x06reward\x18\x02 \x03(\x0b2\x1c.cosmos.base.v1beta1.DecCoinB3\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x01"\xf0\x01\n%CommunityPoolSpendProposalWithDeposit\x12\x1f\n\x05title\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:"title"\x12+\n\x0bdescription\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:"description"\x12\'\n\trecipient\x18\x03 \x01(\tB\x14\xf2\xde\x1f\x10yaml:"recipient"\x12!\n\x06amount\x18\x04 \x01(\tB\x11\xf2\xde\x1f\ryaml:"amount"\x12#\n\x07deposit\x18\x05 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"deposit":\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x01B7Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.distribution.v1beta1.distribution_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01'
    _PARAMS.fields_by_name['community_tax']._options = None
    _PARAMS.fields_by_name['community_tax']._serialized_options = b'\xf2\xde\x1f\x14yaml:"community_tax"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _PARAMS.fields_by_name['base_proposer_reward']._options = None
    _PARAMS.fields_by_name['base_proposer_reward']._serialized_options = b'\xf2\xde\x1f\x1byaml:"base_proposer_reward"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _PARAMS.fields_by_name['bonus_proposer_reward']._options = None
    _PARAMS.fields_by_name['bonus_proposer_reward']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"bonus_proposer_reward"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _PARAMS.fields_by_name['withdraw_addr_enabled']._options = None
    _PARAMS.fields_by_name['withdraw_addr_enabled']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"withdraw_addr_enabled"'
    _PARAMS._options = None
    _PARAMS._serialized_options = b'\x98\xa0\x1f\x00'
    _VALIDATORHISTORICALREWARDS.fields_by_name['cumulative_reward_ratio']._options = None
    _VALIDATORHISTORICALREWARDS.fields_by_name['cumulative_reward_ratio']._serialized_options = b'\xf2\xde\x1f\x1eyaml:"cumulative_reward_ratio"\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00'
    _VALIDATORHISTORICALREWARDS.fields_by_name['reference_count']._options = None
    _VALIDATORHISTORICALREWARDS.fields_by_name['reference_count']._serialized_options = b'\xf2\xde\x1f\x16yaml:"reference_count"'
    _VALIDATORCURRENTREWARDS.fields_by_name['rewards']._options = None
    _VALIDATORCURRENTREWARDS.fields_by_name['rewards']._serialized_options = b'\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00'
    _VALIDATORACCUMULATEDCOMMISSION.fields_by_name['commission']._options = None
    _VALIDATORACCUMULATEDCOMMISSION.fields_by_name['commission']._serialized_options = b'\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00'
    _VALIDATOROUTSTANDINGREWARDS.fields_by_name['rewards']._options = None
    _VALIDATOROUTSTANDINGREWARDS.fields_by_name['rewards']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"rewards"\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00'
    _VALIDATORSLASHEVENT.fields_by_name['validator_period']._options = None
    _VALIDATORSLASHEVENT.fields_by_name['validator_period']._serialized_options = b'\xf2\xde\x1f\x17yaml:"validator_period"'
    _VALIDATORSLASHEVENT.fields_by_name['fraction']._options = None
    _VALIDATORSLASHEVENT.fields_by_name['fraction']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _VALIDATORSLASHEVENTS.fields_by_name['validator_slash_events']._options = None
    _VALIDATORSLASHEVENTS.fields_by_name['validator_slash_events']._serialized_options = b'\xf2\xde\x1f\x1dyaml:"validator_slash_events"\xc8\xde\x1f\x00'
    _VALIDATORSLASHEVENTS._options = None
    _VALIDATORSLASHEVENTS._serialized_options = b'\x98\xa0\x1f\x00'
    _FEEPOOL.fields_by_name['community_pool']._options = None
    _FEEPOOL.fields_by_name['community_pool']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xf2\xde\x1f\x15yaml:"community_pool"'
    _COMMUNITYPOOLSPENDPROPOSAL.fields_by_name['amount']._options = None
    _COMMUNITYPOOLSPENDPROPOSAL.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _COMMUNITYPOOLSPENDPROPOSAL._options = None
    _COMMUNITYPOOLSPENDPROPOSAL._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _DELEGATORSTARTINGINFO.fields_by_name['previous_period']._options = None
    _DELEGATORSTARTINGINFO.fields_by_name['previous_period']._serialized_options = b'\xf2\xde\x1f\x16yaml:"previous_period"'
    _DELEGATORSTARTINGINFO.fields_by_name['stake']._options = None
    _DELEGATORSTARTINGINFO.fields_by_name['stake']._serialized_options = b'\xf2\xde\x1f\x0cyaml:"stake"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _DELEGATORSTARTINGINFO.fields_by_name['height']._options = None
    _DELEGATORSTARTINGINFO.fields_by_name['height']._serialized_options = b'\xf2\xde\x1f\x16yaml:"creation_height"\xea\xde\x1f\x0fcreation_height'
    _DELEGATIONDELEGATORREWARD.fields_by_name['validator_address']._options = None
    _DELEGATIONDELEGATORREWARD.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _DELEGATIONDELEGATORREWARD.fields_by_name['reward']._options = None
    _DELEGATIONDELEGATORREWARD.fields_by_name['reward']._serialized_options = b'\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00'
    _DELEGATIONDELEGATORREWARD._options = None
    _DELEGATIONDELEGATORREWARD._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x01'
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT.fields_by_name['title']._options = None
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT.fields_by_name['title']._serialized_options = b'\xf2\xde\x1f\x0cyaml:"title"'
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT.fields_by_name['description']._options = None
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT.fields_by_name['description']._serialized_options = b'\xf2\xde\x1f\x12yaml:"description"'
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT.fields_by_name['recipient']._options = None
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT.fields_by_name['recipient']._serialized_options = b'\xf2\xde\x1f\x10yaml:"recipient"'
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT.fields_by_name['amount']._options = None
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT.fields_by_name['amount']._serialized_options = b'\xf2\xde\x1f\ryaml:"amount"'
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT.fields_by_name['deposit']._options = None
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT.fields_by_name['deposit']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"deposit"'
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT._options = None
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x01'
    _PARAMS._serialized_start = 134
    _PARAMS._serialized_end = 528
    _VALIDATORHISTORICALREWARDS._serialized_start = 531
    _VALIDATORHISTORICALREWARDS._serialized_end = 763
    _VALIDATORCURRENTREWARDS._serialized_start = 766
    _VALIDATORCURRENTREWARDS._serialized_end = 907
    _VALIDATORACCUMULATEDCOMMISSION._serialized_start = 910
    _VALIDATORACCUMULATEDCOMMISSION._serialized_end = 1045
    _VALIDATOROUTSTANDINGREWARDS._serialized_start = 1048
    _VALIDATOROUTSTANDINGREWARDS._serialized_end = 1195
    _VALIDATORSLASHEVENT._serialized_start = 1198
    _VALIDATORSLASHEVENT._serialized_end = 1340
    _VALIDATORSLASHEVENTS._serialized_start = 1343
    _VALIDATORSLASHEVENTS._serialized_end = 1492
    _FEEPOOL._serialized_start = 1495
    _FEEPOOL._serialized_end = 1637
    _COMMUNITYPOOLSPENDPROPOSAL._serialized_start = 1640
    _COMMUNITYPOOLSPENDPROPOSAL._serialized_end = 1830
    _DELEGATORSTARTINGINFO._serialized_start = 1833
    _DELEGATORSTARTINGINFO._serialized_end = 2051
    _DELEGATIONDELEGATORREWARD._serialized_start = 2054
    _DELEGATIONDELEGATORREWARD._serialized_end = 2247
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT._serialized_start = 2250
    _COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT._serialized_end = 2490




from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from cosmos.mint.v1beta1 import mint_pb2 as _mint_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryAnnualProvisionsRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryAnnualProvisionsResponse(_message.Message):
    __slots__ = ['annual_provisions']
    ANNUAL_PROVISIONS_FIELD_NUMBER: _ClassVar[int]
    annual_provisions: bytes

    def __init__(self, annual_provisions: _Optional[bytes]=...) -> None:
        ...

class QueryInflationRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryInflationResponse(_message.Message):
    __slots__ = ['inflation']
    INFLATION_FIELD_NUMBER: _ClassVar[int]
    inflation: bytes

    def __init__(self, inflation: _Optional[bytes]=...) -> None:
        ...

class QueryParamsRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryParamsResponse(_message.Message):
    __slots__ = ['params']
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _mint_pb2.Params

    def __init__(self, params: _Optional[_Union[(_mint_pb2.Params, _Mapping)]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from cosmos.upgrade.v1beta1 import upgrade_pb2 as _upgrade_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class ClientConsensusStates(_message.Message):
    __slots__ = ['client_id', 'consensus_states']
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_STATES_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    consensus_states: _containers.RepeatedCompositeFieldContainer[ConsensusStateWithHeight]

    def __init__(self, client_id: _Optional[str]=..., consensus_states: _Optional[_Iterable[_Union[(ConsensusStateWithHeight, _Mapping)]]]=...) -> None:
        ...

class ClientUpdateProposal(_message.Message):
    __slots__ = ['description', 'subject_client_id', 'substitute_client_id', 'title']
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    SUBSTITUTE_CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    description: str
    subject_client_id: str
    substitute_client_id: str
    title: str

    def __init__(self, title: _Optional[str]=..., description: _Optional[str]=..., subject_client_id: _Optional[str]=..., substitute_client_id: _Optional[str]=...) -> None:
        ...

class ConsensusStateWithHeight(_message.Message):
    __slots__ = ['consensus_state', 'height']
    CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    consensus_state: _any_pb2.Any
    height: Height

    def __init__(self, height: _Optional[_Union[(Height, _Mapping)]]=..., consensus_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=...) -> None:
        ...

class Height(_message.Message):
    __slots__ = ['revision_height', 'revision_number']
    REVISION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    REVISION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    revision_height: int
    revision_number: int

    def __init__(self, revision_number: _Optional[int]=..., revision_height: _Optional[int]=...) -> None:
        ...

class IdentifiedClientState(_message.Message):
    __slots__ = ['client_id', 'client_state']
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client_state: _any_pb2.Any

    def __init__(self, client_id: _Optional[str]=..., client_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=...) -> None:
        ...

class Params(_message.Message):
    __slots__ = ['allowed_clients']
    ALLOWED_CLIENTS_FIELD_NUMBER: _ClassVar[int]
    allowed_clients: _containers.RepeatedScalarFieldContainer[str]

    def __init__(self, allowed_clients: _Optional[_Iterable[str]]=...) -> None:
        ...

class UpgradeProposal(_message.Message):
    __slots__ = ['description', 'plan', 'title', 'upgraded_client_state']
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    UPGRADED_CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    description: str
    plan: _upgrade_pb2.Plan
    title: str
    upgraded_client_state: _any_pb2.Any

    def __init__(self, title: _Optional[str]=..., description: _Optional[str]=..., plan: _Optional[_Union[(_upgrade_pb2.Plan, _Mapping)]]=..., upgraded_client_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class DenomUnit(_message.Message):
    __slots__ = ['aliases', 'denom', 'exponent']
    ALIASES_FIELD_NUMBER: _ClassVar[int]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    EXPONENT_FIELD_NUMBER: _ClassVar[int]
    aliases: _containers.RepeatedScalarFieldContainer[str]
    denom: str
    exponent: int

    def __init__(self, denom: _Optional[str]=..., exponent: _Optional[int]=..., aliases: _Optional[_Iterable[str]]=...) -> None:
        ...

class Input(_message.Message):
    __slots__ = ['address', 'coins']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COINS_FIELD_NUMBER: _ClassVar[int]
    address: str
    coins: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]

    def __init__(self, address: _Optional[str]=..., coins: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=...) -> None:
        ...

class Metadata(_message.Message):
    __slots__ = ['base', 'denom_units', 'description', 'display', 'name', 'symbol']
    BASE_FIELD_NUMBER: _ClassVar[int]
    DENOM_UNITS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SYMBOL_FIELD_NUMBER: _ClassVar[int]
    base: str
    denom_units: _containers.RepeatedCompositeFieldContainer[DenomUnit]
    description: str
    display: str
    name: str
    symbol: str

    def __init__(self, description: _Optional[str]=..., denom_units: _Optional[_Iterable[_Union[(DenomUnit, _Mapping)]]]=..., base: _Optional[str]=..., display: _Optional[str]=..., name: _Optional[str]=..., symbol: _Optional[str]=...) -> None:
        ...

class Output(_message.Message):
    __slots__ = ['address', 'coins']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COINS_FIELD_NUMBER: _ClassVar[int]
    address: str
    coins: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]

    def __init__(self, address: _Optional[str]=..., coins: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=...) -> None:
        ...

class Params(_message.Message):
    __slots__ = ['default_send_enabled', 'send_enabled']
    DEFAULT_SEND_ENABLED_FIELD_NUMBER: _ClassVar[int]
    SEND_ENABLED_FIELD_NUMBER: _ClassVar[int]
    default_send_enabled: bool
    send_enabled: _containers.RepeatedCompositeFieldContainer[SendEnabled]

    def __init__(self, send_enabled: _Optional[_Iterable[_Union[(SendEnabled, _Mapping)]]]=..., default_send_enabled: bool=...) -> None:
        ...

class SendEnabled(_message.Message):
    __slots__ = ['denom', 'enabled']
    DENOM_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    denom: str
    enabled: bool

    def __init__(self, denom: _Optional[str]=..., enabled: bool=...) -> None:
        ...

class Supply(_message.Message):
    __slots__ = ['total']
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    total: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]

    def __init__(self, total: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+cosmos/base/store/v1beta1/commit_info.proto\x12\x19cosmos.base.store.v1beta1\x1a\x14gogoproto/gogo.proto"^\n\nCommitInfo\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12?\n\x0bstore_infos\x18\x02 \x03(\x0b2$.cosmos.base.store.v1beta1.StoreInfoB\x04\xc8\xde\x1f\x00"W\n\tStoreInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\tcommit_id\x18\x02 \x01(\x0b2#.cosmos.base.store.v1beta1.CommitIDB\x04\xc8\xde\x1f\x00"/\n\x08CommitID\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12\x0c\n\x04hash\x18\x02 \x01(\x0c:\x04\x98\xa0\x1f\x00B*Z(github.com/cosmos/cosmos-sdk/store/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.store.v1beta1.commit_info_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/store/types'
    _COMMITINFO.fields_by_name['store_infos']._options = None
    _COMMITINFO.fields_by_name['store_infos']._serialized_options = b'\xc8\xde\x1f\x00'
    _STOREINFO.fields_by_name['commit_id']._options = None
    _STOREINFO.fields_by_name['commit_id']._serialized_options = b'\xc8\xde\x1f\x00'
    _COMMITID._options = None
    _COMMITID._serialized_options = b'\x98\xa0\x1f\x00'
    _COMMITINFO._serialized_start = 96
    _COMMITINFO._serialized_end = 190
    _STOREINFO._serialized_start = 192
    _STOREINFO._serialized_end = 279
    _COMMITID._serialized_start = 281
    _COMMITID._serialized_end = 328




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ['inactive_duration', 'proof_verification_enabled']
    INACTIVE_DURATION_FIELD_NUMBER: _ClassVar[int]
    PROOF_VERIFICATION_ENABLED_FIELD_NUMBER: _ClassVar[int]
    inactive_duration: _duration_pb2.Duration
    proof_verification_enabled: bool

    def __init__(self, inactive_duration: _Optional[_Union[(_duration_pb2.Duration, _Mapping)]]=..., proof_verification_enabled: bool=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from .....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from .....ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from .....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fibc/core/channel/v1/query.proto\x12\x13ibc.core.channel.v1\x1a\x1fibc/core/client/v1/client.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto":\n\x13QueryChannelRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t"\x8c\x01\n\x14QueryChannelResponse\x12-\n\x07channel\x18\x01 \x01(\x0b2\x1c.ibc.core.channel.v1.Channel\x12\r\n\x05proof\x18\x02 \x01(\x0c\x126\n\x0cproof_height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"R\n\x14QueryChannelsRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\xc0\x01\n\x15QueryChannelsResponse\x128\n\x08channels\x18\x01 \x03(\x0b2&.ibc.core.channel.v1.IdentifiedChannel\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse\x120\n\x06height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"p\n\x1eQueryConnectionChannelsRequest\x12\x12\n\nconnection\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\xca\x01\n\x1fQueryConnectionChannelsResponse\x128\n\x08channels\x18\x01 \x03(\x0b2&.ibc.core.channel.v1.IdentifiedChannel\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse\x120\n\x06height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"E\n\x1eQueryChannelClientStateRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t"\xb4\x01\n\x1fQueryChannelClientStateResponse\x12J\n\x17identified_client_state\x18\x01 \x01(\x0b2).ibc.core.client.v1.IdentifiedClientState\x12\r\n\x05proof\x18\x02 \x01(\x0c\x126\n\x0cproof_height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"z\n!QueryChannelConsensusStateRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x17\n\x0frevision_number\x18\x03 \x01(\x04\x12\x17\n\x0frevision_height\x18\x04 \x01(\x04"\xad\x01\n"QueryChannelConsensusStateResponse\x12-\n\x0fconsensus_state\x18\x01 \x01(\x0b2\x14.google.protobuf.Any\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\r\n\x05proof\x18\x03 \x01(\x0c\x126\n\x0cproof_height\x18\x04 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"U\n\x1cQueryPacketCommitmentRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x04"z\n\x1dQueryPacketCommitmentResponse\x12\x12\n\ncommitment\x18\x01 \x01(\x0c\x12\r\n\x05proof\x18\x02 \x01(\x0c\x126\n\x0cproof_height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"\x80\x01\n\x1dQueryPacketCommitmentsRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12:\n\npagination\x18\x03 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\xc6\x01\n\x1eQueryPacketCommitmentsResponse\x125\n\x0bcommitments\x18\x01 \x03(\x0b2 .ibc.core.channel.v1.PacketState\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse\x120\n\x06height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"R\n\x19QueryPacketReceiptRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x04"u\n\x1aQueryPacketReceiptResponse\x12\x10\n\x08received\x18\x02 \x01(\x08\x12\r\n\x05proof\x18\x03 \x01(\x0c\x126\n\x0cproof_height\x18\x04 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"Z\n!QueryPacketAcknowledgementRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x04"\x84\x01\n"QueryPacketAcknowledgementResponse\x12\x17\n\x0facknowledgement\x18\x01 \x01(\x0c\x12\r\n\x05proof\x18\x02 \x01(\x0c\x126\n\x0cproof_height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"\xaa\x01\n"QueryPacketAcknowledgementsRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12:\n\npagination\x18\x03 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest\x12#\n\x1bpacket_commitment_sequences\x18\x04 \x03(\x04"\xd0\x01\n#QueryPacketAcknowledgementsResponse\x12:\n\x10acknowledgements\x18\x01 \x03(\x0b2 .ibc.core.channel.v1.PacketState\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse\x120\n\x06height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"i\n\x1dQueryUnreceivedPacketsRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12#\n\x1bpacket_commitment_sequences\x18\x03 \x03(\x04"e\n\x1eQueryUnreceivedPacketsResponse\x12\x11\n\tsequences\x18\x01 \x03(\x04\x120\n\x06height\x18\x02 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"_\n\x1aQueryUnreceivedAcksRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x1c\n\x14packet_ack_sequences\x18\x03 \x03(\x04"b\n\x1bQueryUnreceivedAcksResponse\x12\x11\n\tsequences\x18\x01 \x03(\x04\x120\n\x06height\x18\x02 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"F\n\x1fQueryNextSequenceReceiveRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t"\x88\x01\n QueryNextSequenceReceiveResponse\x12\x1d\n\x15next_sequence_receive\x18\x01 \x01(\x04\x12\r\n\x05proof\x18\x02 \x01(\x0c\x126\n\x0cproof_height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x002\x8b\x16\n\x05Query\x12\xa2\x01\n\x07Channel\x12(.ibc.core.channel.v1.QueryChannelRequest\x1a).ibc.core.channel.v1.QueryChannelResponse"B\x82\xd3\xe4\x93\x02<\x12:/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}\x12\x88\x01\n\x08Channels\x12).ibc.core.channel.v1.QueryChannelsRequest\x1a*.ibc.core.channel.v1.QueryChannelsResponse"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/ibc/core/channel/v1/channels\x12\xbf\x01\n\x12ConnectionChannels\x123.ibc.core.channel.v1.QueryConnectionChannelsRequest\x1a4.ibc.core.channel.v1.QueryConnectionChannelsResponse">\x82\xd3\xe4\x93\x028\x126/ibc/core/channel/v1/connections/{connection}/channels\x12\xd0\x01\n\x12ChannelClientState\x123.ibc.core.channel.v1.QueryChannelClientStateRequest\x1a4.ibc.core.channel.v1.QueryChannelClientStateResponse"O\x82\xd3\xe4\x93\x02I\x12G/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/client_state\x12\x92\x02\n\x15ChannelConsensusState\x126.ibc.core.channel.v1.QueryChannelConsensusStateRequest\x1a7.ibc.core.channel.v1.QueryChannelConsensusStateResponse"\x87\x01\x82\xd3\xe4\x93\x02\x80\x01\x12~/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/consensus_state/revision/{revision_number}/height/{revision_height}\x12\xdb\x01\n\x10PacketCommitment\x121.ibc.core.channel.v1.QueryPacketCommitmentRequest\x1a2.ibc.core.channel.v1.QueryPacketCommitmentResponse"`\x82\xd3\xe4\x93\x02Z\x12X/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{sequence}\x12\xd3\x01\n\x11PacketCommitments\x122.ibc.core.channel.v1.QueryPacketCommitmentsRequest\x1a3.ibc.core.channel.v1.QueryPacketCommitmentsResponse"U\x82\xd3\xe4\x93\x02O\x12M/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments\x12\xcf\x01\n\rPacketReceipt\x12..ibc.core.channel.v1.QueryPacketReceiptRequest\x1a/.ibc.core.channel.v1.QueryPacketReceiptResponse"]\x82\xd3\xe4\x93\x02W\x12U/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_receipts/{sequence}\x12\xe3\x01\n\x15PacketAcknowledgement\x126.ibc.core.channel.v1.QueryPacketAcknowledgementRequest\x1a7.ibc.core.channel.v1.QueryPacketAcknowledgementResponse"Y\x82\xd3\xe4\x93\x02S\x12Q/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_acks/{sequence}\x12\xe7\x01\n\x16PacketAcknowledgements\x127.ibc.core.channel.v1.QueryPacketAcknowledgementsRequest\x1a8.ibc.core.channel.v1.QueryPacketAcknowledgementsResponse"Z\x82\xd3\xe4\x93\x02T\x12R/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_acknowledgements\x12\x86\x02\n\x11UnreceivedPackets\x122.ibc.core.channel.v1.QueryUnreceivedPacketsRequest\x1a3.ibc.core.channel.v1.QueryUnreceivedPacketsResponse"\x87\x01\x82\xd3\xe4\x93\x02\x80\x01\x12~/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{packet_commitment_sequences}/unreceived_packets\x12\xf1\x01\n\x0eUnreceivedAcks\x12/.ibc.core.channel.v1.QueryUnreceivedAcksRequest\x1a0.ibc.core.channel.v1.QueryUnreceivedAcksResponse"|\x82\xd3\xe4\x93\x02v\x12t/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{packet_ack_sequences}/unreceived_acks\x12\xd4\x01\n\x13NextSequenceReceive\x124.ibc.core.channel.v1.QueryNextSequenceReceiveRequest\x1a5.ibc.core.channel.v1.QueryNextSequenceReceiveResponse"P\x82\xd3\xe4\x93\x02J\x12H/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/next_sequenceB;Z9github.com/cosmos/ibc-go/v3/modules/core/04-channel/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z9github.com/cosmos/ibc-go/v3/modules/core/04-channel/types'
    _QUERYCHANNELRESPONSE.fields_by_name['proof_height']._options = None
    _QUERYCHANNELRESPONSE.fields_by_name['proof_height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYCHANNELSRESPONSE.fields_by_name['height']._options = None
    _QUERYCHANNELSRESPONSE.fields_by_name['height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYCONNECTIONCHANNELSRESPONSE.fields_by_name['height']._options = None
    _QUERYCONNECTIONCHANNELSRESPONSE.fields_by_name['height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYCHANNELCLIENTSTATERESPONSE.fields_by_name['proof_height']._options = None
    _QUERYCHANNELCLIENTSTATERESPONSE.fields_by_name['proof_height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYCHANNELCONSENSUSSTATERESPONSE.fields_by_name['proof_height']._options = None
    _QUERYCHANNELCONSENSUSSTATERESPONSE.fields_by_name['proof_height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPACKETCOMMITMENTRESPONSE.fields_by_name['proof_height']._options = None
    _QUERYPACKETCOMMITMENTRESPONSE.fields_by_name['proof_height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPACKETCOMMITMENTSRESPONSE.fields_by_name['height']._options = None
    _QUERYPACKETCOMMITMENTSRESPONSE.fields_by_name['height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPACKETRECEIPTRESPONSE.fields_by_name['proof_height']._options = None
    _QUERYPACKETRECEIPTRESPONSE.fields_by_name['proof_height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPACKETACKNOWLEDGEMENTRESPONSE.fields_by_name['proof_height']._options = None
    _QUERYPACKETACKNOWLEDGEMENTRESPONSE.fields_by_name['proof_height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPACKETACKNOWLEDGEMENTSRESPONSE.fields_by_name['height']._options = None
    _QUERYPACKETACKNOWLEDGEMENTSRESPONSE.fields_by_name['height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYUNRECEIVEDPACKETSRESPONSE.fields_by_name['height']._options = None
    _QUERYUNRECEIVEDPACKETSRESPONSE.fields_by_name['height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYUNRECEIVEDACKSRESPONSE.fields_by_name['height']._options = None
    _QUERYUNRECEIVEDACKSRESPONSE.fields_by_name['height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYNEXTSEQUENCERECEIVERESPONSE.fields_by_name['proof_height']._options = None
    _QUERYNEXTSEQUENCERECEIVERESPONSE.fields_by_name['proof_height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERY.methods_by_name['Channel']._options = None
    _QUERY.methods_by_name['Channel']._serialized_options = b'\x82\xd3\xe4\x93\x02<\x12:/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}'
    _QUERY.methods_by_name['Channels']._options = None
    _QUERY.methods_by_name['Channels']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1f\x12\x1d/ibc/core/channel/v1/channels'
    _QUERY.methods_by_name['ConnectionChannels']._options = None
    _QUERY.methods_by_name['ConnectionChannels']._serialized_options = b'\x82\xd3\xe4\x93\x028\x126/ibc/core/channel/v1/connections/{connection}/channels'
    _QUERY.methods_by_name['ChannelClientState']._options = None
    _QUERY.methods_by_name['ChannelClientState']._serialized_options = b'\x82\xd3\xe4\x93\x02I\x12G/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/client_state'
    _QUERY.methods_by_name['ChannelConsensusState']._options = None
    _QUERY.methods_by_name['ChannelConsensusState']._serialized_options = b'\x82\xd3\xe4\x93\x02\x80\x01\x12~/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/consensus_state/revision/{revision_number}/height/{revision_height}'
    _QUERY.methods_by_name['PacketCommitment']._options = None
    _QUERY.methods_by_name['PacketCommitment']._serialized_options = b'\x82\xd3\xe4\x93\x02Z\x12X/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{sequence}'
    _QUERY.methods_by_name['PacketCommitments']._options = None
    _QUERY.methods_by_name['PacketCommitments']._serialized_options = b'\x82\xd3\xe4\x93\x02O\x12M/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments'
    _QUERY.methods_by_name['PacketReceipt']._options = None
    _QUERY.methods_by_name['PacketReceipt']._serialized_options = b'\x82\xd3\xe4\x93\x02W\x12U/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_receipts/{sequence}'
    _QUERY.methods_by_name['PacketAcknowledgement']._options = None
    _QUERY.methods_by_name['PacketAcknowledgement']._serialized_options = b'\x82\xd3\xe4\x93\x02S\x12Q/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_acks/{sequence}'
    _QUERY.methods_by_name['PacketAcknowledgements']._options = None
    _QUERY.methods_by_name['PacketAcknowledgements']._serialized_options = b'\x82\xd3\xe4\x93\x02T\x12R/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_acknowledgements'
    _QUERY.methods_by_name['UnreceivedPackets']._options = None
    _QUERY.methods_by_name['UnreceivedPackets']._serialized_options = b'\x82\xd3\xe4\x93\x02\x80\x01\x12~/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{packet_commitment_sequences}/unreceived_packets'
    _QUERY.methods_by_name['UnreceivedAcks']._options = None
    _QUERY.methods_by_name['UnreceivedAcks']._serialized_options = b'\x82\xd3\xe4\x93\x02v\x12t/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{packet_ack_sequences}/unreceived_acks'
    _QUERY.methods_by_name['NextSequenceReceive']._options = None
    _QUERY.methods_by_name['NextSequenceReceive']._serialized_options = b'\x82\xd3\xe4\x93\x02J\x12H/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/next_sequence'
    _QUERYCHANNELREQUEST._serialized_start = 247
    _QUERYCHANNELREQUEST._serialized_end = 305
    _QUERYCHANNELRESPONSE._serialized_start = 308
    _QUERYCHANNELRESPONSE._serialized_end = 448
    _QUERYCHANNELSREQUEST._serialized_start = 450
    _QUERYCHANNELSREQUEST._serialized_end = 532
    _QUERYCHANNELSRESPONSE._serialized_start = 535
    _QUERYCHANNELSRESPONSE._serialized_end = 727
    _QUERYCONNECTIONCHANNELSREQUEST._serialized_start = 729
    _QUERYCONNECTIONCHANNELSREQUEST._serialized_end = 841
    _QUERYCONNECTIONCHANNELSRESPONSE._serialized_start = 844
    _QUERYCONNECTIONCHANNELSRESPONSE._serialized_end = 1046
    _QUERYCHANNELCLIENTSTATEREQUEST._serialized_start = 1048
    _QUERYCHANNELCLIENTSTATEREQUEST._serialized_end = 1117
    _QUERYCHANNELCLIENTSTATERESPONSE._serialized_start = 1120
    _QUERYCHANNELCLIENTSTATERESPONSE._serialized_end = 1300
    _QUERYCHANNELCONSENSUSSTATEREQUEST._serialized_start = 1302
    _QUERYCHANNELCONSENSUSSTATEREQUEST._serialized_end = 1424
    _QUERYCHANNELCONSENSUSSTATERESPONSE._serialized_start = 1427
    _QUERYCHANNELCONSENSUSSTATERESPONSE._serialized_end = 1600
    _QUERYPACKETCOMMITMENTREQUEST._serialized_start = 1602
    _QUERYPACKETCOMMITMENTREQUEST._serialized_end = 1687
    _QUERYPACKETCOMMITMENTRESPONSE._serialized_start = 1689
    _QUERYPACKETCOMMITMENTRESPONSE._serialized_end = 1811
    _QUERYPACKETCOMMITMENTSREQUEST._serialized_start = 1814
    _QUERYPACKETCOMMITMENTSREQUEST._serialized_end = 1942
    _QUERYPACKETCOMMITMENTSRESPONSE._serialized_start = 1945
    _QUERYPACKETCOMMITMENTSRESPONSE._serialized_end = 2143
    _QUERYPACKETRECEIPTREQUEST._serialized_start = 2145
    _QUERYPACKETRECEIPTREQUEST._serialized_end = 2227
    _QUERYPACKETRECEIPTRESPONSE._serialized_start = 2229
    _QUERYPACKETRECEIPTRESPONSE._serialized_end = 2346
    _QUERYPACKETACKNOWLEDGEMENTREQUEST._serialized_start = 2348
    _QUERYPACKETACKNOWLEDGEMENTREQUEST._serialized_end = 2438
    _QUERYPACKETACKNOWLEDGEMENTRESPONSE._serialized_start = 2441
    _QUERYPACKETACKNOWLEDGEMENTRESPONSE._serialized_end = 2573
    _QUERYPACKETACKNOWLEDGEMENTSREQUEST._serialized_start = 2576
    _QUERYPACKETACKNOWLEDGEMENTSREQUEST._serialized_end = 2746
    _QUERYPACKETACKNOWLEDGEMENTSRESPONSE._serialized_start = 2749
    _QUERYPACKETACKNOWLEDGEMENTSRESPONSE._serialized_end = 2957
    _QUERYUNRECEIVEDPACKETSREQUEST._serialized_start = 2959
    _QUERYUNRECEIVEDPACKETSREQUEST._serialized_end = 3064
    _QUERYUNRECEIVEDPACKETSRESPONSE._serialized_start = 3066
    _QUERYUNRECEIVEDPACKETSRESPONSE._serialized_end = 3167
    _QUERYUNRECEIVEDACKSREQUEST._serialized_start = 3169
    _QUERYUNRECEIVEDACKSREQUEST._serialized_end = 3264
    _QUERYUNRECEIVEDACKSRESPONSE._serialized_start = 3266
    _QUERYUNRECEIVEDACKSRESPONSE._serialized_end = 3364
    _QUERYNEXTSEQUENCERECEIVEREQUEST._serialized_start = 3366
    _QUERYNEXTSEQUENCERECEIVEREQUEST._serialized_end = 3436
    _QUERYNEXTSEQUENCERECEIVERESPONSE._serialized_start = 3439
    _QUERYNEXTSEQUENCERECEIVERESPONSE._serialized_end = 3575
    _QUERY._serialized_start = 3578
    _QUERY._serialized_end = 6405




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ....cosmos.auth.v1beta1 import query_pb2 as cosmos_dot_auth_dot_v1beta1_dot_query__pb2

class QueryStub(object):
    'Query defines the gRPC querier service.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.Accounts = channel.unary_unary('/cosmos.auth.v1beta1.Query/Accounts', request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountsRequest.SerializeToString, response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountsResponse.FromString)
        self.Account = channel.unary_unary('/cosmos.auth.v1beta1.Query/Account', request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountRequest.SerializeToString, response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountResponse.FromString)
        self.Params = channel.unary_unary('/cosmos.auth.v1beta1.Query/Params', request_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString, response_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString)

class QueryServicer(object):
    'Query defines the gRPC querier service.\n    '

    def Accounts(self, request, context):
        'Accounts returns all the existing accounts\n\n        Since: cosmos-sdk 0.43\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Account(self, request, context):
        'Account returns account details based on address.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        'Params queries all parameters.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {'Accounts': grpc.unary_unary_rpc_method_handler(servicer.Accounts, request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountsRequest.FromString, response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountsResponse.SerializeToString), 'Account': grpc.unary_unary_rpc_method_handler(servicer.Account, request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountRequest.FromString, response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountResponse.SerializeToString), 'Params': grpc.unary_unary_rpc_method_handler(servicer.Params, request_deserializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString, response_serializer=cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('cosmos.auth.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Query defines the gRPC querier service.\n    '

    @staticmethod
    def Accounts(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.auth.v1beta1.Query/Accounts', cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountsRequest.SerializeToString, cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Account(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.auth.v1beta1.Query/Account', cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountRequest.SerializeToString, cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryAccountResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.auth.v1beta1.Query/Params', cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString, cosmos_dot_auth_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




from tendermint.crypto import proof_pb2 as _proof_pb2
from tendermint.types import types_pb2 as _types_pb2
from tendermint.crypto import keys_pb2 as _keys_pb2
from tendermint.types import params_pb2 as _params_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor
DUPLICATE_VOTE: EvidenceType
LIGHT_CLIENT_ATTACK: EvidenceType
NEW: CheckTxType
RECHECK: CheckTxType
UNKNOWN: EvidenceType

class BlockParams(_message.Message):
    __slots__ = ['max_bytes', 'max_gas']
    MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    MAX_GAS_FIELD_NUMBER: _ClassVar[int]
    max_bytes: int
    max_gas: int

    def __init__(self, max_bytes: _Optional[int]=..., max_gas: _Optional[int]=...) -> None:
        ...

class ConsensusParams(_message.Message):
    __slots__ = ['block', 'evidence', 'validator', 'version']
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    block: BlockParams
    evidence: _params_pb2.EvidenceParams
    validator: _params_pb2.ValidatorParams
    version: _params_pb2.VersionParams

    def __init__(self, block: _Optional[_Union[(BlockParams, _Mapping)]]=..., evidence: _Optional[_Union[(_params_pb2.EvidenceParams, _Mapping)]]=..., validator: _Optional[_Union[(_params_pb2.ValidatorParams, _Mapping)]]=..., version: _Optional[_Union[(_params_pb2.VersionParams, _Mapping)]]=...) -> None:
        ...

class Event(_message.Message):
    __slots__ = ['attributes', 'type']
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    attributes: _containers.RepeatedCompositeFieldContainer[EventAttribute]
    type: str

    def __init__(self, type: _Optional[str]=..., attributes: _Optional[_Iterable[_Union[(EventAttribute, _Mapping)]]]=...) -> None:
        ...

class EventAttribute(_message.Message):
    __slots__ = ['index', 'key', 'value']
    INDEX_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    index: bool
    key: bytes
    value: bytes

    def __init__(self, key: _Optional[bytes]=..., value: _Optional[bytes]=..., index: bool=...) -> None:
        ...

class Evidence(_message.Message):
    __slots__ = ['height', 'time', 'total_voting_power', 'type', 'validator']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    height: int
    time: _timestamp_pb2.Timestamp
    total_voting_power: int
    type: EvidenceType
    validator: Validator

    def __init__(self, type: _Optional[_Union[(EvidenceType, str)]]=..., validator: _Optional[_Union[(Validator, _Mapping)]]=..., height: _Optional[int]=..., time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., total_voting_power: _Optional[int]=...) -> None:
        ...

class LastCommitInfo(_message.Message):
    __slots__ = ['round', 'votes']
    ROUND_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    round: int
    votes: _containers.RepeatedCompositeFieldContainer[VoteInfo]

    def __init__(self, round: _Optional[int]=..., votes: _Optional[_Iterable[_Union[(VoteInfo, _Mapping)]]]=...) -> None:
        ...

class Request(_message.Message):
    __slots__ = ['apply_snapshot_chunk', 'begin_block', 'check_tx', 'commit', 'deliver_tx', 'echo', 'end_block', 'flush', 'info', 'init_chain', 'list_snapshots', 'load_snapshot_chunk', 'offer_snapshot', 'query', 'set_option']
    APPLY_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    BEGIN_BLOCK_FIELD_NUMBER: _ClassVar[int]
    CHECK_TX_FIELD_NUMBER: _ClassVar[int]
    COMMIT_FIELD_NUMBER: _ClassVar[int]
    DELIVER_TX_FIELD_NUMBER: _ClassVar[int]
    ECHO_FIELD_NUMBER: _ClassVar[int]
    END_BLOCK_FIELD_NUMBER: _ClassVar[int]
    FLUSH_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    INIT_CHAIN_FIELD_NUMBER: _ClassVar[int]
    LIST_SNAPSHOTS_FIELD_NUMBER: _ClassVar[int]
    LOAD_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    OFFER_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    SET_OPTION_FIELD_NUMBER: _ClassVar[int]
    apply_snapshot_chunk: RequestApplySnapshotChunk
    begin_block: RequestBeginBlock
    check_tx: RequestCheckTx
    commit: RequestCommit
    deliver_tx: RequestDeliverTx
    echo: RequestEcho
    end_block: RequestEndBlock
    flush: RequestFlush
    info: RequestInfo
    init_chain: RequestInitChain
    list_snapshots: RequestListSnapshots
    load_snapshot_chunk: RequestLoadSnapshotChunk
    offer_snapshot: RequestOfferSnapshot
    query: RequestQuery
    set_option: RequestSetOption

    def __init__(self, echo: _Optional[_Union[(RequestEcho, _Mapping)]]=..., flush: _Optional[_Union[(RequestFlush, _Mapping)]]=..., info: _Optional[_Union[(RequestInfo, _Mapping)]]=..., set_option: _Optional[_Union[(RequestSetOption, _Mapping)]]=..., init_chain: _Optional[_Union[(RequestInitChain, _Mapping)]]=..., query: _Optional[_Union[(RequestQuery, _Mapping)]]=..., begin_block: _Optional[_Union[(RequestBeginBlock, _Mapping)]]=..., check_tx: _Optional[_Union[(RequestCheckTx, _Mapping)]]=..., deliver_tx: _Optional[_Union[(RequestDeliverTx, _Mapping)]]=..., end_block: _Optional[_Union[(RequestEndBlock, _Mapping)]]=..., commit: _Optional[_Union[(RequestCommit, _Mapping)]]=..., list_snapshots: _Optional[_Union[(RequestListSnapshots, _Mapping)]]=..., offer_snapshot: _Optional[_Union[(RequestOfferSnapshot, _Mapping)]]=..., load_snapshot_chunk: _Optional[_Union[(RequestLoadSnapshotChunk, _Mapping)]]=..., apply_snapshot_chunk: _Optional[_Union[(RequestApplySnapshotChunk, _Mapping)]]=...) -> None:
        ...

class RequestApplySnapshotChunk(_message.Message):
    __slots__ = ['chunk', 'index', 'sender']
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    index: int
    sender: str

    def __init__(self, index: _Optional[int]=..., chunk: _Optional[bytes]=..., sender: _Optional[str]=...) -> None:
        ...

class RequestBeginBlock(_message.Message):
    __slots__ = ['byzantine_validators', 'hash', 'header', 'last_commit_info']
    BYZANTINE_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LAST_COMMIT_INFO_FIELD_NUMBER: _ClassVar[int]
    byzantine_validators: _containers.RepeatedCompositeFieldContainer[Evidence]
    hash: bytes
    header: _types_pb2.Header
    last_commit_info: LastCommitInfo

    def __init__(self, hash: _Optional[bytes]=..., header: _Optional[_Union[(_types_pb2.Header, _Mapping)]]=..., last_commit_info: _Optional[_Union[(LastCommitInfo, _Mapping)]]=..., byzantine_validators: _Optional[_Iterable[_Union[(Evidence, _Mapping)]]]=...) -> None:
        ...

class RequestCheckTx(_message.Message):
    __slots__ = ['tx', 'type']
    TX_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    tx: bytes
    type: CheckTxType

    def __init__(self, tx: _Optional[bytes]=..., type: _Optional[_Union[(CheckTxType, str)]]=...) -> None:
        ...

class RequestCommit(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class RequestDeliverTx(_message.Message):
    __slots__ = ['tx']
    TX_FIELD_NUMBER: _ClassVar[int]
    tx: bytes

    def __init__(self, tx: _Optional[bytes]=...) -> None:
        ...

class RequestEcho(_message.Message):
    __slots__ = ['message']
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str

    def __init__(self, message: _Optional[str]=...) -> None:
        ...

class RequestEndBlock(_message.Message):
    __slots__ = ['height']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int

    def __init__(self, height: _Optional[int]=...) -> None:
        ...

class RequestFlush(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class RequestInfo(_message.Message):
    __slots__ = ['block_version', 'p2p_version', 'version']
    BLOCK_VERSION_FIELD_NUMBER: _ClassVar[int]
    P2P_VERSION_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    block_version: int
    p2p_version: int
    version: str

    def __init__(self, version: _Optional[str]=..., block_version: _Optional[int]=..., p2p_version: _Optional[int]=...) -> None:
        ...

class RequestInitChain(_message.Message):
    __slots__ = ['app_state_bytes', 'chain_id', 'consensus_params', 'initial_height', 'time', 'validators']
    APP_STATE_BYTES_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PARAMS_FIELD_NUMBER: _ClassVar[int]
    INITIAL_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    app_state_bytes: bytes
    chain_id: str
    consensus_params: ConsensusParams
    initial_height: int
    time: _timestamp_pb2.Timestamp
    validators: _containers.RepeatedCompositeFieldContainer[ValidatorUpdate]

    def __init__(self, time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., chain_id: _Optional[str]=..., consensus_params: _Optional[_Union[(ConsensusParams, _Mapping)]]=..., validators: _Optional[_Iterable[_Union[(ValidatorUpdate, _Mapping)]]]=..., app_state_bytes: _Optional[bytes]=..., initial_height: _Optional[int]=...) -> None:
        ...

class RequestListSnapshots(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class RequestLoadSnapshotChunk(_message.Message):
    __slots__ = ['chunk', 'format', 'height']
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    chunk: int
    format: int
    height: int

    def __init__(self, height: _Optional[int]=..., format: _Optional[int]=..., chunk: _Optional[int]=...) -> None:
        ...

class RequestOfferSnapshot(_message.Message):
    __slots__ = ['app_hash', 'snapshot']
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    app_hash: bytes
    snapshot: Snapshot

    def __init__(self, snapshot: _Optional[_Union[(Snapshot, _Mapping)]]=..., app_hash: _Optional[bytes]=...) -> None:
        ...

class RequestQuery(_message.Message):
    __slots__ = ['data', 'height', 'path', 'prove']
    DATA_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    PROVE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    height: int
    path: str
    prove: bool

    def __init__(self, data: _Optional[bytes]=..., path: _Optional[str]=..., height: _Optional[int]=..., prove: bool=...) -> None:
        ...

class RequestSetOption(_message.Message):
    __slots__ = ['key', 'value']
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str

    def __init__(self, key: _Optional[str]=..., value: _Optional[str]=...) -> None:
        ...

class Response(_message.Message):
    __slots__ = ['apply_snapshot_chunk', 'begin_block', 'check_tx', 'commit', 'deliver_tx', 'echo', 'end_block', 'exception', 'flush', 'info', 'init_chain', 'list_snapshots', 'load_snapshot_chunk', 'offer_snapshot', 'query', 'set_option']
    APPLY_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    BEGIN_BLOCK_FIELD_NUMBER: _ClassVar[int]
    CHECK_TX_FIELD_NUMBER: _ClassVar[int]
    COMMIT_FIELD_NUMBER: _ClassVar[int]
    DELIVER_TX_FIELD_NUMBER: _ClassVar[int]
    ECHO_FIELD_NUMBER: _ClassVar[int]
    END_BLOCK_FIELD_NUMBER: _ClassVar[int]
    EXCEPTION_FIELD_NUMBER: _ClassVar[int]
    FLUSH_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    INIT_CHAIN_FIELD_NUMBER: _ClassVar[int]
    LIST_SNAPSHOTS_FIELD_NUMBER: _ClassVar[int]
    LOAD_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    OFFER_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    SET_OPTION_FIELD_NUMBER: _ClassVar[int]
    apply_snapshot_chunk: ResponseApplySnapshotChunk
    begin_block: ResponseBeginBlock
    check_tx: ResponseCheckTx
    commit: ResponseCommit
    deliver_tx: ResponseDeliverTx
    echo: ResponseEcho
    end_block: ResponseEndBlock
    exception: ResponseException
    flush: ResponseFlush
    info: ResponseInfo
    init_chain: ResponseInitChain
    list_snapshots: ResponseListSnapshots
    load_snapshot_chunk: ResponseLoadSnapshotChunk
    offer_snapshot: ResponseOfferSnapshot
    query: ResponseQuery
    set_option: ResponseSetOption

    def __init__(self, exception: _Optional[_Union[(ResponseException, _Mapping)]]=..., echo: _Optional[_Union[(ResponseEcho, _Mapping)]]=..., flush: _Optional[_Union[(ResponseFlush, _Mapping)]]=..., info: _Optional[_Union[(ResponseInfo, _Mapping)]]=..., set_option: _Optional[_Union[(ResponseSetOption, _Mapping)]]=..., init_chain: _Optional[_Union[(ResponseInitChain, _Mapping)]]=..., query: _Optional[_Union[(ResponseQuery, _Mapping)]]=..., begin_block: _Optional[_Union[(ResponseBeginBlock, _Mapping)]]=..., check_tx: _Optional[_Union[(ResponseCheckTx, _Mapping)]]=..., deliver_tx: _Optional[_Union[(ResponseDeliverTx, _Mapping)]]=..., end_block: _Optional[_Union[(ResponseEndBlock, _Mapping)]]=..., commit: _Optional[_Union[(ResponseCommit, _Mapping)]]=..., list_snapshots: _Optional[_Union[(ResponseListSnapshots, _Mapping)]]=..., offer_snapshot: _Optional[_Union[(ResponseOfferSnapshot, _Mapping)]]=..., load_snapshot_chunk: _Optional[_Union[(ResponseLoadSnapshotChunk, _Mapping)]]=..., apply_snapshot_chunk: _Optional[_Union[(ResponseApplySnapshotChunk, _Mapping)]]=...) -> None:
        ...

class ResponseApplySnapshotChunk(_message.Message):
    __slots__ = ['refetch_chunks', 'reject_senders', 'result']

    class Result(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ABORT: ResponseApplySnapshotChunk.Result
    ACCEPT: ResponseApplySnapshotChunk.Result
    REFETCH_CHUNKS_FIELD_NUMBER: _ClassVar[int]
    REJECT_SENDERS_FIELD_NUMBER: _ClassVar[int]
    REJECT_SNAPSHOT: ResponseApplySnapshotChunk.Result
    RESULT_FIELD_NUMBER: _ClassVar[int]
    RETRY: ResponseApplySnapshotChunk.Result
    RETRY_SNAPSHOT: ResponseApplySnapshotChunk.Result
    UNKNOWN: ResponseApplySnapshotChunk.Result
    refetch_chunks: _containers.RepeatedScalarFieldContainer[int]
    reject_senders: _containers.RepeatedScalarFieldContainer[str]
    result: ResponseApplySnapshotChunk.Result

    def __init__(self, result: _Optional[_Union[(ResponseApplySnapshotChunk.Result, str)]]=..., refetch_chunks: _Optional[_Iterable[int]]=..., reject_senders: _Optional[_Iterable[str]]=...) -> None:
        ...

class ResponseBeginBlock(_message.Message):
    __slots__ = ['events']
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedCompositeFieldContainer[Event]

    def __init__(self, events: _Optional[_Iterable[_Union[(Event, _Mapping)]]]=...) -> None:
        ...

class ResponseCheckTx(_message.Message):
    __slots__ = ['code', 'codespace', 'data', 'events', 'gas_used', 'gas_wanted', 'info', 'log']
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    GAS_USED_FIELD_NUMBER: _ClassVar[int]
    GAS_WANTED_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    code: int
    codespace: str
    data: bytes
    events: _containers.RepeatedCompositeFieldContainer[Event]
    gas_used: int
    gas_wanted: int
    info: str
    log: str

    def __init__(self, code: _Optional[int]=..., data: _Optional[bytes]=..., log: _Optional[str]=..., info: _Optional[str]=..., gas_wanted: _Optional[int]=..., gas_used: _Optional[int]=..., events: _Optional[_Iterable[_Union[(Event, _Mapping)]]]=..., codespace: _Optional[str]=...) -> None:
        ...

class ResponseCommit(_message.Message):
    __slots__ = ['data', 'retain_height']
    DATA_FIELD_NUMBER: _ClassVar[int]
    RETAIN_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    retain_height: int

    def __init__(self, data: _Optional[bytes]=..., retain_height: _Optional[int]=...) -> None:
        ...

class ResponseDeliverTx(_message.Message):
    __slots__ = ['code', 'codespace', 'data', 'events', 'gas_used', 'gas_wanted', 'info', 'log']
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    GAS_USED_FIELD_NUMBER: _ClassVar[int]
    GAS_WANTED_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    code: int
    codespace: str
    data: bytes
    events: _containers.RepeatedCompositeFieldContainer[Event]
    gas_used: int
    gas_wanted: int
    info: str
    log: str

    def __init__(self, code: _Optional[int]=..., data: _Optional[bytes]=..., log: _Optional[str]=..., info: _Optional[str]=..., gas_wanted: _Optional[int]=..., gas_used: _Optional[int]=..., events: _Optional[_Iterable[_Union[(Event, _Mapping)]]]=..., codespace: _Optional[str]=...) -> None:
        ...

class ResponseEcho(_message.Message):
    __slots__ = ['message']
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str

    def __init__(self, message: _Optional[str]=...) -> None:
        ...

class ResponseEndBlock(_message.Message):
    __slots__ = ['consensus_param_updates', 'events', 'validator_updates']
    CONSENSUS_PARAM_UPDATES_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_UPDATES_FIELD_NUMBER: _ClassVar[int]
    consensus_param_updates: ConsensusParams
    events: _containers.RepeatedCompositeFieldContainer[Event]
    validator_updates: _containers.RepeatedCompositeFieldContainer[ValidatorUpdate]

    def __init__(self, validator_updates: _Optional[_Iterable[_Union[(ValidatorUpdate, _Mapping)]]]=..., consensus_param_updates: _Optional[_Union[(ConsensusParams, _Mapping)]]=..., events: _Optional[_Iterable[_Union[(Event, _Mapping)]]]=...) -> None:
        ...

class ResponseException(_message.Message):
    __slots__ = ['error']
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: str

    def __init__(self, error: _Optional[str]=...) -> None:
        ...

class ResponseFlush(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class ResponseInfo(_message.Message):
    __slots__ = ['app_version', 'data', 'last_block_app_hash', 'last_block_height', 'version']
    APP_VERSION_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_APP_HASH_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    app_version: int
    data: str
    last_block_app_hash: bytes
    last_block_height: int
    version: str

    def __init__(self, data: _Optional[str]=..., version: _Optional[str]=..., app_version: _Optional[int]=..., last_block_height: _Optional[int]=..., last_block_app_hash: _Optional[bytes]=...) -> None:
        ...

class ResponseInitChain(_message.Message):
    __slots__ = ['app_hash', 'consensus_params', 'validators']
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PARAMS_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    app_hash: bytes
    consensus_params: ConsensusParams
    validators: _containers.RepeatedCompositeFieldContainer[ValidatorUpdate]

    def __init__(self, consensus_params: _Optional[_Union[(ConsensusParams, _Mapping)]]=..., validators: _Optional[_Iterable[_Union[(ValidatorUpdate, _Mapping)]]]=..., app_hash: _Optional[bytes]=...) -> None:
        ...

class ResponseListSnapshots(_message.Message):
    __slots__ = ['snapshots']
    SNAPSHOTS_FIELD_NUMBER: _ClassVar[int]
    snapshots: _containers.RepeatedCompositeFieldContainer[Snapshot]

    def __init__(self, snapshots: _Optional[_Iterable[_Union[(Snapshot, _Mapping)]]]=...) -> None:
        ...

class ResponseLoadSnapshotChunk(_message.Message):
    __slots__ = ['chunk']
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes

    def __init__(self, chunk: _Optional[bytes]=...) -> None:
        ...

class ResponseOfferSnapshot(_message.Message):
    __slots__ = ['result']

    class Result(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ABORT: ResponseOfferSnapshot.Result
    ACCEPT: ResponseOfferSnapshot.Result
    REJECT: ResponseOfferSnapshot.Result
    REJECT_FORMAT: ResponseOfferSnapshot.Result
    REJECT_SENDER: ResponseOfferSnapshot.Result
    RESULT_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN: ResponseOfferSnapshot.Result
    result: ResponseOfferSnapshot.Result

    def __init__(self, result: _Optional[_Union[(ResponseOfferSnapshot.Result, str)]]=...) -> None:
        ...

class ResponseQuery(_message.Message):
    __slots__ = ['code', 'codespace', 'height', 'index', 'info', 'key', 'log', 'proof_ops', 'value']
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    PROOF_OPS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    code: int
    codespace: str
    height: int
    index: int
    info: str
    key: bytes
    log: str
    proof_ops: _proof_pb2.ProofOps
    value: bytes

    def __init__(self, code: _Optional[int]=..., log: _Optional[str]=..., info: _Optional[str]=..., index: _Optional[int]=..., key: _Optional[bytes]=..., value: _Optional[bytes]=..., proof_ops: _Optional[_Union[(_proof_pb2.ProofOps, _Mapping)]]=..., height: _Optional[int]=..., codespace: _Optional[str]=...) -> None:
        ...

class ResponseSetOption(_message.Message):
    __slots__ = ['code', 'info', 'log']
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    code: int
    info: str
    log: str

    def __init__(self, code: _Optional[int]=..., log: _Optional[str]=..., info: _Optional[str]=...) -> None:
        ...

class Snapshot(_message.Message):
    __slots__ = ['chunks', 'format', 'hash', 'height', 'metadata']
    CHUNKS_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    chunks: int
    format: int
    hash: bytes
    height: int
    metadata: bytes

    def __init__(self, height: _Optional[int]=..., format: _Optional[int]=..., chunks: _Optional[int]=..., hash: _Optional[bytes]=..., metadata: _Optional[bytes]=...) -> None:
        ...

class TxResult(_message.Message):
    __slots__ = ['height', 'index', 'result', 'tx']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    TX_FIELD_NUMBER: _ClassVar[int]
    height: int
    index: int
    result: ResponseDeliverTx
    tx: bytes

    def __init__(self, height: _Optional[int]=..., index: _Optional[int]=..., tx: _Optional[bytes]=..., result: _Optional[_Union[(ResponseDeliverTx, _Mapping)]]=...) -> None:
        ...

class Validator(_message.Message):
    __slots__ = ['address', 'power']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    POWER_FIELD_NUMBER: _ClassVar[int]
    address: bytes
    power: int

    def __init__(self, address: _Optional[bytes]=..., power: _Optional[int]=...) -> None:
        ...

class ValidatorUpdate(_message.Message):
    __slots__ = ['power', 'pub_key']
    POWER_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    power: int
    pub_key: _keys_pb2.PublicKey

    def __init__(self, pub_key: _Optional[_Union[(_keys_pb2.PublicKey, _Mapping)]]=..., power: _Optional[int]=...) -> None:
        ...

class VoteInfo(_message.Message):
    __slots__ = ['signed_last_block', 'validator']
    SIGNED_LAST_BLOCK_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    signed_last_block: bool
    validator: Validator

    def __init__(self, validator: _Optional[_Union[(Validator, _Mapping)]]=..., signed_last_block: bool=...) -> None:
        ...

class CheckTxType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class EvidenceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!sentinel/provider/v2/params.proto\x12\x14sentinel.provider.v2\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/base/v1beta1/coin.proto"\x81\x01\n\x06Params\x120\n\x07deposit\x18\x01 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12E\n\rstaking_share\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00B;Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.provider.v2.params_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _PARAMS.fields_by_name['deposit']._options = None
    _PARAMS.fields_by_name['deposit']._serialized_options = b'\xc8\xde\x1f\x00'
    _PARAMS.fields_by_name['staking_share']._options = None
    _PARAMS.fields_by_name['staking_share']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _PARAMS._serialized_start = 114
    _PARAMS._serialized_end = 243




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ccosmos/bank/v1beta1/tx.proto\x12\x13cosmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x1ecosmos/bank/v1beta1/bank.proto"\xca\x01\n\x07MsgSend\x12-\n\x0cfrom_address\x18\x01 \x01(\tB\x17\xf2\xde\x1f\x13yaml:"from_address"\x12)\n\nto_address\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:"to_address"\x12[\n\x06amount\x18\x03 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x11\n\x0fMsgSendResponse"z\n\x0cMsgMultiSend\x120\n\x06inputs\x18\x01 \x03(\x0b2\x1a.cosmos.bank.v1beta1.InputB\x04\xc8\xde\x1f\x00\x122\n\x07outputs\x18\x02 \x03(\x0b2\x1b.cosmos.bank.v1beta1.OutputB\x04\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x00"\x16\n\x14MsgMultiSendResponse2\xac\x01\n\x03Msg\x12J\n\x04Send\x12\x1c.cosmos.bank.v1beta1.MsgSend\x1a$.cosmos.bank.v1beta1.MsgSendResponse\x12Y\n\tMultiSend\x12!.cosmos.bank.v1beta1.MsgMultiSend\x1a).cosmos.bank.v1beta1.MsgMultiSendResponseB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
    _MSGSEND.fields_by_name['from_address']._options = None
    _MSGSEND.fields_by_name['from_address']._serialized_options = b'\xf2\xde\x1f\x13yaml:"from_address"'
    _MSGSEND.fields_by_name['to_address']._options = None
    _MSGSEND.fields_by_name['to_address']._serialized_options = b'\xf2\xde\x1f\x11yaml:"to_address"'
    _MSGSEND.fields_by_name['amount']._options = None
    _MSGSEND.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _MSGSEND._options = None
    _MSGSEND._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGMULTISEND.fields_by_name['inputs']._options = None
    _MSGMULTISEND.fields_by_name['inputs']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGMULTISEND.fields_by_name['outputs']._options = None
    _MSGMULTISEND.fields_by_name['outputs']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGMULTISEND._options = None
    _MSGMULTISEND._serialized_options = b'\xe8\xa0\x1f\x00'
    _MSGSEND._serialized_start = 140
    _MSGSEND._serialized_end = 342
    _MSGSENDRESPONSE._serialized_start = 344
    _MSGSENDRESPONSE._serialized_end = 361
    _MSGMULTISEND._serialized_start = 363
    _MSGMULTISEND._serialized_end = 485
    _MSGMULTISENDRESPONSE._serialized_start = 487
    _MSGMULTISENDRESPONSE._serialized_end = 509
    _MSG._serialized_start = 512
    _MSG._serialized_end = 684




from google.api import annotations_pb2 as _annotations_pb2
from cosmos.base.abci.v1beta1 import abci_pb2 as _abci_pb2
from cosmos.tx.v1beta1 import tx_pb2 as _tx_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from tendermint.types import block_pb2 as _block_pb2
from tendermint.types import types_pb2 as _types_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
BROADCAST_MODE_ASYNC: BroadcastMode
BROADCAST_MODE_BLOCK: BroadcastMode
BROADCAST_MODE_SYNC: BroadcastMode
BROADCAST_MODE_UNSPECIFIED: BroadcastMode
DESCRIPTOR: _descriptor.FileDescriptor
ORDER_BY_ASC: OrderBy
ORDER_BY_DESC: OrderBy
ORDER_BY_UNSPECIFIED: OrderBy

class BroadcastTxRequest(_message.Message):
    __slots__ = ['mode', 'tx_bytes']
    MODE_FIELD_NUMBER: _ClassVar[int]
    TX_BYTES_FIELD_NUMBER: _ClassVar[int]
    mode: BroadcastMode
    tx_bytes: bytes

    def __init__(self, tx_bytes: _Optional[bytes]=..., mode: _Optional[_Union[(BroadcastMode, str)]]=...) -> None:
        ...

class BroadcastTxResponse(_message.Message):
    __slots__ = ['tx_response']
    TX_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    tx_response: _abci_pb2.TxResponse

    def __init__(self, tx_response: _Optional[_Union[(_abci_pb2.TxResponse, _Mapping)]]=...) -> None:
        ...

class GetBlockWithTxsRequest(_message.Message):
    __slots__ = ['height', 'pagination']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    height: int
    pagination: _pagination_pb2.PageRequest

    def __init__(self, height: _Optional[int]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class GetBlockWithTxsResponse(_message.Message):
    __slots__ = ['block', 'block_id', 'pagination', 'txs']
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    TXS_FIELD_NUMBER: _ClassVar[int]
    block: _block_pb2.Block
    block_id: _types_pb2.BlockID
    pagination: _pagination_pb2.PageResponse
    txs: _containers.RepeatedCompositeFieldContainer[_tx_pb2.Tx]

    def __init__(self, txs: _Optional[_Iterable[_Union[(_tx_pb2.Tx, _Mapping)]]]=..., block_id: _Optional[_Union[(_types_pb2.BlockID, _Mapping)]]=..., block: _Optional[_Union[(_block_pb2.Block, _Mapping)]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class GetTxRequest(_message.Message):
    __slots__ = ['hash']
    HASH_FIELD_NUMBER: _ClassVar[int]
    hash: str

    def __init__(self, hash: _Optional[str]=...) -> None:
        ...

class GetTxResponse(_message.Message):
    __slots__ = ['tx', 'tx_response']
    TX_FIELD_NUMBER: _ClassVar[int]
    TX_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    tx: _tx_pb2.Tx
    tx_response: _abci_pb2.TxResponse

    def __init__(self, tx: _Optional[_Union[(_tx_pb2.Tx, _Mapping)]]=..., tx_response: _Optional[_Union[(_abci_pb2.TxResponse, _Mapping)]]=...) -> None:
        ...

class GetTxsEventRequest(_message.Message):
    __slots__ = ['events', 'order_by', 'pagination']
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedScalarFieldContainer[str]
    order_by: OrderBy
    pagination: _pagination_pb2.PageRequest

    def __init__(self, events: _Optional[_Iterable[str]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=..., order_by: _Optional[_Union[(OrderBy, str)]]=...) -> None:
        ...

class GetTxsEventResponse(_message.Message):
    __slots__ = ['pagination', 'tx_responses', 'txs']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    TXS_FIELD_NUMBER: _ClassVar[int]
    TX_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    tx_responses: _containers.RepeatedCompositeFieldContainer[_abci_pb2.TxResponse]
    txs: _containers.RepeatedCompositeFieldContainer[_tx_pb2.Tx]

    def __init__(self, txs: _Optional[_Iterable[_Union[(_tx_pb2.Tx, _Mapping)]]]=..., tx_responses: _Optional[_Iterable[_Union[(_abci_pb2.TxResponse, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class SimulateRequest(_message.Message):
    __slots__ = ['tx', 'tx_bytes']
    TX_BYTES_FIELD_NUMBER: _ClassVar[int]
    TX_FIELD_NUMBER: _ClassVar[int]
    tx: _tx_pb2.Tx
    tx_bytes: bytes

    def __init__(self, tx: _Optional[_Union[(_tx_pb2.Tx, _Mapping)]]=..., tx_bytes: _Optional[bytes]=...) -> None:
        ...

class SimulateResponse(_message.Message):
    __slots__ = ['gas_info', 'result']
    GAS_INFO_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    gas_info: _abci_pb2.GasInfo
    result: _abci_pb2.Result

    def __init__(self, gas_info: _Optional[_Union[(_abci_pb2.GasInfo, _Mapping)]]=..., result: _Optional[_Union[(_abci_pb2.Result, _Mapping)]]=...) -> None:
        ...

class OrderBy(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class BroadcastMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmos.distribution.v1beta1 import distribution_pb2 as _distribution_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class DelegatorStartingInfoRecord(_message.Message):
    __slots__ = ['delegator_address', 'starting_info', 'validator_address']
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    STARTING_INFO_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    starting_info: _distribution_pb2.DelegatorStartingInfo
    validator_address: str

    def __init__(self, delegator_address: _Optional[str]=..., validator_address: _Optional[str]=..., starting_info: _Optional[_Union[(_distribution_pb2.DelegatorStartingInfo, _Mapping)]]=...) -> None:
        ...

class DelegatorWithdrawInfo(_message.Message):
    __slots__ = ['delegator_address', 'withdraw_address']
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    WITHDRAW_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    withdraw_address: str

    def __init__(self, delegator_address: _Optional[str]=..., withdraw_address: _Optional[str]=...) -> None:
        ...

class GenesisState(_message.Message):
    __slots__ = ['delegator_starting_infos', 'delegator_withdraw_infos', 'fee_pool', 'outstanding_rewards', 'params', 'previous_proposer', 'validator_accumulated_commissions', 'validator_current_rewards', 'validator_historical_rewards', 'validator_slash_events']
    DELEGATOR_STARTING_INFOS_FIELD_NUMBER: _ClassVar[int]
    DELEGATOR_WITHDRAW_INFOS_FIELD_NUMBER: _ClassVar[int]
    FEE_POOL_FIELD_NUMBER: _ClassVar[int]
    OUTSTANDING_REWARDS_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    PREVIOUS_PROPOSER_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ACCUMULATED_COMMISSIONS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_CURRENT_REWARDS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_HISTORICAL_REWARDS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SLASH_EVENTS_FIELD_NUMBER: _ClassVar[int]
    delegator_starting_infos: _containers.RepeatedCompositeFieldContainer[DelegatorStartingInfoRecord]
    delegator_withdraw_infos: _containers.RepeatedCompositeFieldContainer[DelegatorWithdrawInfo]
    fee_pool: _distribution_pb2.FeePool
    outstanding_rewards: _containers.RepeatedCompositeFieldContainer[ValidatorOutstandingRewardsRecord]
    params: _distribution_pb2.Params
    previous_proposer: str
    validator_accumulated_commissions: _containers.RepeatedCompositeFieldContainer[ValidatorAccumulatedCommissionRecord]
    validator_current_rewards: _containers.RepeatedCompositeFieldContainer[ValidatorCurrentRewardsRecord]
    validator_historical_rewards: _containers.RepeatedCompositeFieldContainer[ValidatorHistoricalRewardsRecord]
    validator_slash_events: _containers.RepeatedCompositeFieldContainer[ValidatorSlashEventRecord]

    def __init__(self, params: _Optional[_Union[(_distribution_pb2.Params, _Mapping)]]=..., fee_pool: _Optional[_Union[(_distribution_pb2.FeePool, _Mapping)]]=..., delegator_withdraw_infos: _Optional[_Iterable[_Union[(DelegatorWithdrawInfo, _Mapping)]]]=..., previous_proposer: _Optional[str]=..., outstanding_rewards: _Optional[_Iterable[_Union[(ValidatorOutstandingRewardsRecord, _Mapping)]]]=..., validator_accumulated_commissions: _Optional[_Iterable[_Union[(ValidatorAccumulatedCommissionRecord, _Mapping)]]]=..., validator_historical_rewards: _Optional[_Iterable[_Union[(ValidatorHistoricalRewardsRecord, _Mapping)]]]=..., validator_current_rewards: _Optional[_Iterable[_Union[(ValidatorCurrentRewardsRecord, _Mapping)]]]=..., delegator_starting_infos: _Optional[_Iterable[_Union[(DelegatorStartingInfoRecord, _Mapping)]]]=..., validator_slash_events: _Optional[_Iterable[_Union[(ValidatorSlashEventRecord, _Mapping)]]]=...) -> None:
        ...

class ValidatorAccumulatedCommissionRecord(_message.Message):
    __slots__ = ['accumulated', 'validator_address']
    ACCUMULATED_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    accumulated: _distribution_pb2.ValidatorAccumulatedCommission
    validator_address: str

    def __init__(self, validator_address: _Optional[str]=..., accumulated: _Optional[_Union[(_distribution_pb2.ValidatorAccumulatedCommission, _Mapping)]]=...) -> None:
        ...

class ValidatorCurrentRewardsRecord(_message.Message):
    __slots__ = ['rewards', 'validator_address']
    REWARDS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    rewards: _distribution_pb2.ValidatorCurrentRewards
    validator_address: str

    def __init__(self, validator_address: _Optional[str]=..., rewards: _Optional[_Union[(_distribution_pb2.ValidatorCurrentRewards, _Mapping)]]=...) -> None:
        ...

class ValidatorHistoricalRewardsRecord(_message.Message):
    __slots__ = ['period', 'rewards', 'validator_address']
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    REWARDS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    period: int
    rewards: _distribution_pb2.ValidatorHistoricalRewards
    validator_address: str

    def __init__(self, validator_address: _Optional[str]=..., period: _Optional[int]=..., rewards: _Optional[_Union[(_distribution_pb2.ValidatorHistoricalRewards, _Mapping)]]=...) -> None:
        ...

class ValidatorOutstandingRewardsRecord(_message.Message):
    __slots__ = ['outstanding_rewards', 'validator_address']
    OUTSTANDING_REWARDS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    outstanding_rewards: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    validator_address: str

    def __init__(self, validator_address: _Optional[str]=..., outstanding_rewards: _Optional[_Iterable[_Union[(_coin_pb2.DecCoin, _Mapping)]]]=...) -> None:
        ...

class ValidatorSlashEventRecord(_message.Message):
    __slots__ = ['height', 'period', 'validator_address', 'validator_slash_event']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SLASH_EVENT_FIELD_NUMBER: _ClassVar[int]
    height: int
    period: int
    validator_address: str
    validator_slash_event: _distribution_pb2.ValidatorSlashEvent

    def __init__(self, validator_address: _Optional[str]=..., height: _Optional[int]=..., period: _Optional[int]=..., validator_slash_event: _Optional[_Union[(_distribution_pb2.ValidatorSlashEvent, _Mapping)]]=...) -> None:
        ...
